@@ -1,3 +1,7 @@
 from .connections.websocket import WebSocket
 from .rubika import Client
-from .tools import Tools
\ No newline at end of file
+from .tools import Tools
+
+
+__version__ = '4.6.3'
+__author__ = 'Shayan Heidari'
\ No newline at end of file
