@@ -26,9 +26,17 @@ class WebSocket(object):
         async for message in self.handShake(choice(self.__WSaddress)):
             if message.get('type') == 'messenger':
                 data = loads(self.enc.decrypt(message.get('data_enc')))
-                if message_updates:
-                    for m_u in data.get('message_updates'): yield m_u
+                if message_updates and chat_updates and show_notifications:
+                    yield data
+                elif chat_updates and message_updates:
+                    data['show_notifications'] = None
+                    yield data
+                elif message_updates:
+                    for i in data.get('message_updates'):
+                        yield i
                 elif chat_updates:
-                    for c_u in data.get('chat_updates'): yield c_u
-                else:
-                    for s_n in data.get('show_notifications'): yield s_n
\ No newline at end of file
+                    for i in data.get('chat_updates'):
+                        yield i
+                elif show_notifications:
+                    for i in data.get('show_notifications'):
+                        yield i
\ No newline at end of file
