@@ -615,21 +615,5 @@ class Client(object):
     def Handler(self, func):
         async def runner():
             async for i in self.websocket():
-                self.new_message = i
-                message = i.get('message')
-                self.chat_type = message.get('type')
-                if self.chat_type == 'Text':
-                    self.text = message.get('text')
-                self.author_type = message.get('author_type')
-                self.author_object_guid = message.get('author_object_guid')
-                self.message_id = i.get('message_id')
-                self.action = i.get('action')
-                self.object_guid = i.get('object_guid')
                 await func(i)
-        asyncio.run(runner())
-
-    def getGroupMessageHandler(self):
-        pass
-
-    async def reply(self, text):
-        return await self.sendMessage(self.new_message.get('object_guid'), text, reply_to_message_id=self.new_message.get('message_id'))
\ No newline at end of file
+        asyncio.run(runner())
\ No newline at end of file
