@@ -1,5 +1,4 @@
 from re import findall
-from urlextract import URLExtract
 from io import BytesIO
 from pybase64 import b64encode
 try: from PIL import Image
@@ -7,8 +6,7 @@ except ModuleNotFoundError: Image = None
 
 
 class Tools(object):
-	def __init__(self):
-		self.extractor = URLExtract()
+	def __init__(self): pass
 
 	def analyzeString(self, text):
 		Results = []
@@ -33,7 +31,6 @@ class Tools(object):
 			for mIndex, mWord in zip(mResult, monos):
 				Results.append({'from_index': mIndex, 'length': len(mWord), 'type': 'Mono'})
 
-		print(Results)
 		return {'metadata': Results, 'string': realText}
 
 	def adsFinder(self, string):
